@@ -411,6 +411,9 @@ public class TskData {
         TSK_FS_TYPE_ISO9660_DETECT (0x00000800),        ///< ISO9660 auto detection
         TSK_FS_TYPE_HFS (0x00001000),   ///< HFS file system
         TSK_FS_TYPE_HFS_DETECT (0x00001000),    ///< HFS auto detection
+        TSK_FS_TYPE_EXT4 (0x00002000),  ///< Ext4 file system
+        TSK_FS_TYPE_YAFFS2(0x00003000),  ///< YAFFS2 file system
+        TSK_FS_TYPE_YAFFS2_DETECT(0x00003000),   ///< YAFFS2 auto detection
         TSK_FS_TYPE_UNSUPP (0xffffffff);        ///< Unsupported file system
 		
 		private int value;
