@@ -33,7 +33,7 @@
 
 
 /* config.h must be first */
-#include "tsk3/tsk_tools_i.h"
+#include "tsk/tsk_tools_i.h"
 
 #include <stdio.h>
 #include "fiwalk.h"
@@ -202,6 +202,8 @@ static string fw_empty("");
  */
 void comment(const char *format,...)
 {
+    if(opt_body_file) return;           // no comments in body file
+
     char buf[1024];
     va_list ap;
     va_start(ap, format);
@@ -426,7 +428,7 @@ int af_display_as_hex(const char *segname)
 }
 #endif
 
-#if _MSC_VER
+#ifdef TSK_WIN32
 
 static int convert(TSK_TCHAR *OPTARG, char **_opt_arg)
 {
@@ -455,7 +457,6 @@ static int convert(TSK_TCHAR *OPTARG, char **_opt_arg)
 int main(int argc, char * const *argv1)
 {
     int ch;
-//    extern int optind;
     const char *arff_fn = 0;
     const char *text_fn = 0;
     string *xml_fn = 0;
@@ -482,9 +483,7 @@ int main(int argc, char * const *argv1)
 	argv = (TSK_TCHAR * const*) argv1;
 #endif
 	
-
- //   while ((ch = GETOPT(argc, argv, _TSK_T("A:a:C:dEfG:gmv1IMX:S:T:VZn:c:b:xOzh?"))) > 0 ) { // s: removed
-    while ((ch = GETOPT(argc, argv, _TSK_T("A:a:C:dfG:gbmv1IMX:T:VZn:c:xOzh?"))) > 0 ) { // s: removed
+    while ((ch = GETOPT(argc, argv, _TSK_T("A:a:C:dfG:gmv1IMX:T:VZn:c:b:xOzh?"))) > 0 ) { // s: removed
 	switch (ch) {
 	case _TSK_T('1'): opt_sha1++;break;
 	case _TSK_T('m'):
@@ -494,7 +493,7 @@ int main(int argc, char * const *argv1)
 	    t = stdout;
 	    break;
 	case _TSK_T('A'):
-#ifdef _MSC_VER
+#ifdef TSK_WIN32
 		convert(OPTARG, &opt_arg);
 		arff_fn = opt_arg;
 #else
@@ -517,7 +516,7 @@ int main(int argc, char * const *argv1)
 	case _TSK_T('O'): opt_allocated_only=true; break;
 //	case _TSK_T('S'): sectorhash_size = TATOI(OPTARG); break;
 	case _TSK_T('T'):
-#ifdef _MSC_VER
+#ifdef TSK_WIN32
 		convert(OPTARG, &opt_arg);
 		text_fn = opt_arg;
 #else
@@ -526,7 +525,7 @@ int main(int argc, char * const *argv1)
 		break;
 	case _TSK_T('V'): print_version();exit(0);
 	case _TSK_T('X'): 
-#ifdef _MSC_VER
+#ifdef TSK_WIN32
 		convert(OPTARG, &opt_arg);
 		xml_fn = new string(opt_arg);
 #else
@@ -536,7 +535,7 @@ int main(int argc, char * const *argv1)
 	case _TSK_T('x'): opt_x = true;break;
 	case _TSK_T('Z'): opt_zap = true;break;
 	case _TSK_T('a'): 
-#ifdef _MSC_VER
+#ifdef TSK_WIN32
 		convert(OPTARG, &opt_arg);
 		audit_file = opt_arg;
 #else
@@ -544,7 +543,7 @@ int main(int argc, char * const *argv1)
 #endif
 		break;
 	case _TSK_T('c'): 
-#ifdef _MSC_VER
+#ifdef TSK_WIN32
 		convert(OPTARG, &opt_arg);
 		config_file = opt_arg;
 #else
@@ -575,7 +574,7 @@ int main(int argc, char * const *argv1)
 	argv += OPTIND;
 	argv1 += OPTIND;
 
-#ifdef _MSC_VER
+#ifdef TSK_WIN32
 		convert(argv[0],&argv_0);
 		const char *filename = argv_0;
 #else
@@ -715,7 +714,7 @@ int main(int argc, char * const *argv1)
     signal(SIGINFO,sig_info);
 #endif
 
-#if _MSC_VER
+#ifdef TSK_WIN32
     int count = process_image_file(argc,argv1,audit_file,sector_size);
     if(count<=0 || sector_size!=512){
 	comment("Retrying with 512 byte sector size.");
